@@ -12,5 +12,5 @@ fun_text <- '
 print_iris <- function() iris
 '
 test_that("roc_eval_text parses diffused roxygen comments to Rd text", {
-  expect_true(roc_eval_text(roxygen2::rd_roclet(), fun_text)[[1L]]$is_valid())
+  expect_error(roc_eval_text(roxygen2::rd_roclet(), fun_text)[[1L]], NA)
 })
